@@ -20,7 +20,7 @@ describe 'cinder' do
       it {
         is_expected.to contain_cinder_config('DEFAULT/transport_url').with(:value => '<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('DEFAULT/rpc_response_timeout').with(:value => '<SERVICE DEFAULT>')
-        is_expected.to contain_cinder_config('DEFAULT/control_exchange').with(:value => 'openstack')
+        is_expected.to contain_cinder_config('DEFAULT/control_exchange').with(:value => '<SERVICE DEFAULT>')
       }
 
       it { is_expected.to contain_oslo__messaging__notifications('cinder_config').with(
@@ -205,16 +205,6 @@ describe 'cinder' do
       }
     end
 
-    context 'with APIs set for Mitaka (proposed)' do
-      let :params do
-        {
-          :enable_v3_api => true,
-        }
-      end
-
-      it { is_expected.to contain_cinder_config('DEFAULT/enable_v3_api').with_value(true) }
-    end
-
     context 'with image_conversion_dir' do
       let :params do
         req_params.merge({
@@ -247,6 +237,16 @@ describe 'cinder' do
       it { is_expected.to contain_cinder_config('DEFAULT/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673') }
     end
 
+    context 'with control_exchange' do
+      let :params do
+        req_params.merge({
+          :control_exchange => 'cinder',
+        })
+      end
+
+      it { is_expected.to contain_cinder_config('DEFAULT/control_exchange').with_value('cinder') }
+    end
+
     context 'with notifications' do
       let :params do
         req_params.merge({
